@@ -5,17 +5,14 @@
 # A simple method for displaying the hydropathic character of a protein. 
 # Journal of Molecular Biology, 157(1), 105–32.
 
-hydrophobicity<-function(seq,scale){
-  # Setting the hydrophobicity scale
-  M<-c("KyteDoolittle","AbrahamLeo",   "BullBreese",   "Guy",          "Miyazawa",     "Roseman",      "Wolfenden",   
-       "Wilson",       "Cowan3.4",     "Aboderin",     "Sweet",        "Eisenberg",    "HoppWoods",    "Manavalan",   
-       "BlackMould",   "Fauchere",     "Janin",        "Rao",          "Tanford",      "Cowan7.5",     "Chothia",
-       "Rose")
-  scale<-pmatch(scale,M)
+hydrophobicity<-function(seq,scale="KyteDoolittle"){
   # Loading hydrophobicity scales
   data(H, envir = environment())
   H<-H
+  # Setting the hydrophobicity scale
+  M<-names(H)
+  scale<-match.arg(scale,M)
   # Sum the hydrophobicity of each amino acid and divide them between the sequence length
-  # Return the GRAVY value rounded to 2 decimals
-  round(sum(H[[scale]][s2c(toupper(seq))],na.rm = TRUE)/nchar(seq),2)
+  # Return the GRAVY value
+  sum(H[[scale]][strsplit(seq,"")[[1]]],na.rm = TRUE)/nchar(seq)
 }
