@@ -5,8 +5,8 @@ test.pI<- function(){
   # Theoretical pI: 9.88
   
   # CHECK pI VALUE
-  checkEquals(round(pI("QWGRRCCGWGPGRRYCVRWC","Bje"),2),9.88)
+  checkEquals(pI("QWGRRCCGWGPGRRYCVRWC","Bjellqvist"),9.88,tolerance = 0.01)
   
   # CHECK OUTPUT CLASS
-  checkTrue(is.numeric(pI("QWGRRCCGWGPGRRYCVRWC","Bje")))
+  checkTrue(is.numeric(pI("QWGRRCCGWGPGRRYCVRWC","Bjellqvist")))
 }
\ No newline at end of file
